@@ -1,6 +1,9 @@
+from zipfile import BadZipFile
+
+from bs4 import BeautifulSoup
 import io
 import zipfile
-from os.path import join
+import os
 
 from django.core.files.storage import default_storage
 from django.template.backends.django import DjangoTemplates
@@ -48,25 +51,38 @@ class ZipAbstractEngine(DjangoTemplates):
     app_dirname = None
     sub_dirname = None
     template_class = None
-    zip_root_file = None
+    zip_root_files = None
 
     def get_template_content(self, filename):
         """
         Returns the contents of a template before modification, as a string.
         """
         try:
-            template_buffer = io.BytesIO(default_storage.open(filename, 'rb').read())
-            with zipfile.ZipFile(template_buffer, 'r') as zip_file:
-                b_content = zip_file.read(self.zip_root_file)
-                return b_content.decode()
-        except KeyError:
+            with default_storage.open(filename, 'rb') as template_file:
+                template_buffer = io.BytesIO(template_file.read())
+
+                with zipfile.ZipFile(template_buffer, 'r') as zip_file:
+                    soup = BeautifulSoup('', 'html.parser')
+                    global_tag = soup.new_tag("global-merged")
+
+                    for file_to_merge in self.zip_root_files:
+                        name, _ = os.path.splitext(file_to_merge)
+                        content = zip_file.read(file_to_merge).decode()
+                        content_soup = BeautifulSoup(content, 'xml')
+                        tag_file = content_soup.new_tag('{0}-merged'.format(name.replace('/', '-')))
+                        tag_file.append(content_soup)
+                        global_tag.append(tag_file)
+
+                    soup.append(global_tag)
+                    return str(soup)
+        except (KeyError, BadZipFile):
             raise TemplateDoesNotExist('Bad format.')
 
     @cached_property
     def template_dirs(self):
         t_dirs = super().template_dirs
         if self.sub_dirname:
-            t_dirs += tuple([join(p, self.sub_dirname) for p in t_dirs])
+            t_dirs += tuple([os.path.join(p, self.sub_dirname) for p in t_dirs])
         return t_dirs
 
     def from_string(self, template_code, **kwargs):
@@ -80,7 +96,7 @@ class ZipAbstractEngine(DjangoTemplates):
         if default_storage.exists(filename):
             return filename
         for directory in self.template_dirs:
-            abstract_path = default_storage.generate_filename(join(directory, filename))
+            abstract_path = default_storage.generate_filename(os.path.join(directory, filename))
             if default_storage.exists(abstract_path):
                 return abstract_path
         raise TemplateDoesNotExist(f'Unknown: {filename}')
