@@ -1,6 +1,9 @@
+from pathlib import Path
+
 from bs4 import BeautifulSoup
 from django.conf import settings
 from django.template.context import make_context
+from django.template.exceptions import TemplateDoesNotExist
 
 from .abstract import AbstractTemplate, ZipAbstractEngine
 from .utils import modify_content_document
@@ -167,10 +170,11 @@ class OdtTemplate(AbstractTemplate):
     def render(self, context=None, request=None):
         context = make_context(context, request)
         rendered = self.template.render(context)
-        soup = BeautifulSoup(rendered, features='xml')
+        soup = BeautifulSoup(rendered, features='html.parser')
         soup = self.clean(soup)
         soup = self.replace_inputs(soup)
-        odt_content = modify_content_document(self.template_path, 'content.xml', str(soup))
+
+        odt_content = modify_content_document(self.template_path, ['content.xml', 'styles.xml'], soup)
         for key, image in context.get('images', {}).items():
             odt_content = add_image_in_odt_template(odt_content, image, key)
         return odt_content
@@ -189,9 +193,16 @@ class OdtEngine(ZipAbstractEngine):
     sub_dirname = getattr(settings, 'ODT_ENGINE_SUB_DIRNAME', 'odt')
     app_dirname = getattr(settings, 'ODT_ENGINE_APP_DIRNAME', 'templates')
     template_class = OdtTemplate
-    zip_root_file = 'content.xml'
+    zip_root_files = ['content.xml', 'styles.xml']
 
     def __init__(self, params):
         params['OPTIONS'].setdefault('builtins', [])
         params['OPTIONS']['builtins'].extend(['template_engines.templatetags.odt_tags'])
         super().__init__(params)
+
+    def get_template_path(self, filename):
+        path = super().get_template_path(filename)
+        path_object = Path(path)
+        if path_object.suffix.lower() != '.odt':
+            raise TemplateDoesNotExist('This is not an ODT file')
+        return path
